Utilities
=========

Ensembles
---------
.. automodule:: xclim.ensembles
   :members:
   :undoc-members:
   :show-inheritance:
   :noindex:

Subsetting
----------

.. automodule:: xclim.subset
   :members:
   :undoc-members:
   :show-inheritance:
   :noindex:

Run-Length Calculations
-----------------------

.. automodule:: xclim.run_length
   :members:
   :undoc-members:
   :show-inheritance:
   :noindex:
